==> igniteui-angular-charts-18.0.0.tgz: package/esm2015/lib/CategoryChartToolbarProvider.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { DomainChartToolbarProvider } from "./DomainChartToolbarProvider";
import { markType } from "igniteui-angular-core";
/**
 * @hidden
 */
export let CategoryChartToolbarProvider = /*@__PURE__*/ (() => {
    class CategoryChartToolbarProvider extends DomainChartToolbarProvider {
        constructor() {
            super(...arguments);
            this.y = null;
        }
        e(a, b) {
            let c = a;
            switch (b.name) {
                case "ShowGridlines":
                    {
                        let d = b;
                        d.isChecked = c.adz != null;
                    }
                    break;
            }
        }
        u(a, b, c, d) {
            let e = a;
            switch (b) {
                case "XAxisMajorStroke":
                    this.f("ShowGridlines", 2, a.adz != null);
                    break;
            }
        }
        k(a, b) {
            let c = a;
            if (this.c(b, "ShowGridlines")) {
                if (c.adz == null) {
                    if (this.y != null) {
                        c.adz = this.y;
                    }
                    else {
                        c.adz = c.dataChart.z2;
                    }
                }
            }
            else {
                if (c.adz != null) {
                    this.y = c.adz;
                    c.adz = null;
                }
            }
        }
    }
    CategoryChartToolbarProvider.$t = markType(CategoryChartToolbarProvider, 'CategoryChartToolbarProvider', DomainChartToolbarProvider.$);
    return CategoryChartToolbarProvider;
})();

==> igniteui-angular-charts-18.1.0.tgz: package/esm2015/lib/CategoryChartToolbarProvider.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { DomainChartToolbarProvider } from "./DomainChartToolbarProvider";
import { markType } from "igniteui-angular-core";
/**
 * @hidden
 */
export let CategoryChartToolbarProvider = /*@__PURE__*/ (() => {
    class CategoryChartToolbarProvider extends DomainChartToolbarProvider {
        constructor() {
            super(...arguments);
            this.ad = null;
        }
        g(a, b) {
            let c = a;
            switch (b.name) {
                case "ShowGridlines":
                    {
                        let d = b;
                        d.isChecked = c.afi != null;
                    }
                    break;
            }
        }
        z(a, b, c, d) {
            let e = a;
            switch (b) {
                case "XAxisMajorStroke":
                    this.h("ShowGridlines", 2, a.afi != null);
                    break;
            }
        }
        p(a, b) {
            let c = a;
            if (this.c(b, "ShowGridlines")) {
                if (c.afi == null) {
                    if (this.ad != null) {
                        c.afi = this.ad;
                    }
                    else {
                        c.afi = c.dataChart.z6;
                    }
                }
            }
            else {
                if (c.afi != null) {
                    this.ad = c.afi;
                    c.afi = null;
                }
            }
        }
    }
    CategoryChartToolbarProvider.$t = markType(CategoryChartToolbarProvider, 'CategoryChartToolbarProvider', DomainChartToolbarProvider.$);
    return CategoryChartToolbarProvider;
})();
